# New Prod config

## 20220902_crab_test_nodes

## Short description of the config

Generated as:

```
lstmcpipe_generate_config PathConfigAllSkyTesting --prod_id 20220902_crab_test_nodes --kwargs dec=dec_2276
```

Then edited manually to replace the path model with `/fefs/aswg/data/models/AllSky/20220518_allsky_dec2276_tuned/dec_2276/`

lstchain config copied from `/fefs/aswg/data/models/AllSky/20220518_allsky_dec2276_tuned/dec_2276/`

## Why this config is needed 

Config to produce the new test nodes using Crab dec training.
See https://github.com/cta-observatory/lst-sim-config/issues/49#issuecomment-1235392024


